@@ -1,6 +1,14 @@
-predDensity <- function(model = NULL, obs = NULL, pred = NULL, separate = TRUE, type = c("both"), legend.pos = "topright", main = "Density of predicted values", na.rm = TRUE, rm.dup = FALSE) {
-  # version 1.5 (6 May 2022)
-  
+predDensity <- function(model = NULL, obs = NULL, pred = NULL, separate = TRUE, type = "both", ci = NA, legend.pos = "topright", main = "Density of predicted values", na.rm = TRUE, rm.dup = FALSE, ...) {
+  # version 1.6 (9 Jan 2023)
+
+  if (!is.na(ci)) {
+    # if (separate) {
+      # message("Because 'ci' is not NULL, 'separate' was changed to FALSE.")
+      separate <- FALSE
+    # }
+    if (!is.numeric(ci) || length(ci) != 1 || ci < 0 || ci > 1) stop("'ci' must be either NULL or a numeric value between 0 and 1.")  # new
+  }
+
   if (is.null(obs) && is.null(model)) {
     if (is.null(pred)) stop ("You must provide either 'model' or 'pred'.")
     separate <- FALSE
@@ -10,7 +18,7 @@ predDensity <- function(model = NULL, obs = NULL, pred = NULL, separate = TRUE,
   obspred <- inputMunch(model, obs, pred, na.rm = na.rm, rm.dup = rm.dup)
   obs <- obspred[ , "obs"]
   pred <- obspred[ , "pred"]
-  
+
   # if (is.null(obs)) {
   #   if (is.null(pred)) stop ("You must provide either 'model' or 'pred'.")
   #   # if (separate) message("'obs' not provided, so 'separate' automatically set to FALSE.")
@@ -19,19 +27,19 @@ predDensity <- function(model = NULL, obs = NULL, pred = NULL, separate = TRUE,
   # } else {
   #   if (length(obs) != length(pred)) stop("'obs' and 'pred' must have the same length.")
   # }
-  
+
   pred0 <- pred[obs == 0]
   pred1 <- pred[obs == 1]
-  
+
   type <- match.arg(type, c("histogram", "density", "both"))
-  
+
   #yy <- NULL
   #if ("histogram" %in% type) yy <- c(yy, pmax(hist0$density, hist1$density))
   #if ("density" %in% type) yy <- c(yy, pmax(hist0$density, hist1$density))
   #plot(x = c(0, 1), y = pmax(hist0$density, hist1$density), type = "n", xlab = "Predicted value", ylab = "Density")
-  
+
   rslt <- vector("list")
-  
+
   if (type %in% c("density", "both")) {  # "density" %in% type
     if (!separate) {
       dens <- density(pred)
@@ -48,37 +56,47 @@ predDensity <- function(model = NULL, obs = NULL, pred = NULL, separate = TRUE,
     }
     plot(x = xrange, y = yrange, xlab = "Predicted value", ylab = "Density", type = "n", main = main)
   }
-  
+
   if (type %in% c("histogram", "both")) {  # "histogram" %in% type
     #brks <- ifelse(is.null(breaks), "Sturges", breaks)
-    hist0 <- hist(pred0, plot = FALSE)
-    hist1 <- hist(pred1, plot = FALSE)
+    hist0 <- hist(pred0, plot = FALSE, ...)
+    hist1 <- hist(pred1, plot = FALSE, ...)
     if (type == "histogram") {  # !("density" %in% type)
       yrange <- range(hist0$density, hist1$density, finite = TRUE)
       plot(x = c(0, 1), y = yrange, type = "n", xlab = "Predicted value", ylab = "Density", main = main)
     }
     if (!separate) {
-      histogram <- hist(c(pred0, pred1), freq = FALSE, col = "grey20", add = TRUE)
+      histogram <- hist(c(pred0, pred1), freq = FALSE, col = "grey40", add = TRUE, ...)
       rslt[["histogram"]] <- histogram
       } else {
-      hist(pred1, freq = FALSE, col = "grey20", add = TRUE)
-      hist(pred0, freq = FALSE, col = "darkgrey", density = 40, angle = 45, add = TRUE)
+      hist(pred1, freq = FALSE, col = "grey40", add = TRUE, ...)
+      hist(pred0, freq = FALSE, col = "darkgrey", density = 40, angle = 45, add = TRUE, ...)
       rslt[["histogram_obs1"]] <- hist1
       rslt[["histogram_obs0"]] <- hist0
-      if (legend.pos != "n" && type == "histogram") legend(legend.pos, legend = c("absences", "presences"), fill = c("darkgrey", "grey20"), border = NA, density = c(40, NA), bty = "n")
+      if (legend.pos != "n" && type == "histogram") legend(legend.pos, legend = c("absences", "presences"), fill = c("darkgrey", "grey40"), border = NA, density = c(40, NA), bty = "n")
     }
   }
-  
+
   if (type %in% c("density", "both")) {  # "density" %in% type
     if (!separate) {
-      lines(dens, col = "black", lwd = 2)
+      lines(dens, col = "grey10", lwd = 2)
     } else {
-      lines(dens1, col = "black", lwd = 2)
+      lines(dens1, col = "grey10", lwd = 2)
       lines(dens0, col = "darkgrey", lty = 5, lwd = 2)
-      if (!is.na(legend.pos) && legend.pos != "n" && type == "density") legend(legend.pos, legend = c("absences", "presences"), col = c("darkgrey", "black"), lty = c(5, 1), bty = "n")
-      if (!is.na(legend.pos) && legend.pos != "n" && type == "both") legend(legend.pos, legend = c("absences", "presences"), fill = c("darkgrey", "grey20"), border = NA, lty = c(5, 1), col = c("darkgrey", "grey15"), density = c(40, NA), bty = "n")
+      if (!is.na(legend.pos) && legend.pos != "n" && type == "density") legend(legend.pos, legend = c("absences", "presences"), col = c("darkgrey", "grey10"), lty = c(5, 1), bty = "n")
+      if (!is.na(legend.pos) && legend.pos != "n" && type == "both") legend(legend.pos, legend = c("absences", "presences"), fill = c("darkgrey", "grey40"), border = NA, lty = c(5, 1), col = c("darkgrey", "grey20"), density = c(40, NA), bty = "n")
     }
   }
-  
+
+  if (!is.na(ci)) {
+    quants <- quantile(pred, probs = c(1 - ci, ci))
+    maxs <- vector("numeric")
+    if ("density" %in% names(rslt)) maxs <- c(maxs, max(rslt$density$y))
+    if ("histogram" %in% names(rslt)) maxs <- c(maxs, max(rslt$histogram$density))
+    # abline(v = quants, col = "darkgreen")
+    rect(quants[1], 0, quants[2], max(maxs), col = adjustcolor("darkgreen", alpha.f = 0.3), border = NA)
+    abline(v = mean(pred), lwd = 2, col = "darkblue")
+  }
+
   return(rslt)
 }
